@@ -1,9 +1,9 @@
 #ifndef _TKCONFIG
 #define _TKCONFIG
-#define ANSI_SIGNED_CHAR 1
 #define CAN_COPSTASH_SET_NULL 1
 #define HAS_SVIV_NOMG 1
 #define HAS_SVNV_NOMG 1
+#define HAVE_INTTYPES_H 1
 #define HAVE_LIMITS_H 1
 #define HAVE_SYS_SELECT_H 1
 #define HAVE_SYS_TIME_H 1
@@ -15,5 +15,4 @@
 #define USE_PREGCOMP_31027 1
 #define USE_PROTOTYPE 1
 #define USE_REGEXP_511 1
-#define USE_XFT_FONTS 1
 #endif
